The input variable of ovs_scan is changed from 'template' to
'format'. template is a keyword in C++.

Signed-off-by: Harold Lim <haro...@vmware.com>
---
 lib/util.c |    8 ++++----
 lib/util.h |    2 +-
 2 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/lib/util.h b/lib/util.h
index 975d1a9..2fb97d2 100644
--- a/lib/util.h
+++ b/lib/util.h
@@ -296,7 +296,7 @@ str_to_ullong(const char *s, int base, unsigned long long 
*ull)
     return str_to_llong(s, base, (long long *) ull);
 }
 
-bool ovs_scan(const char *s, const char *template, ...) SCANF_FORMAT(2, 3);
+bool ovs_scan(const char *s, const char *format, ...) SCANF_FORMAT(2, 3);
 
 bool str_to_double(const char *, double *);
 
diff --git a/lib/util.c b/lib/util.c
index 0227822..9f37350 100644
--- a/lib/util.c
+++ b/lib/util.c
@@ -1465,7 +1465,7 @@ scan_chars(const char *s, const struct scan_spec *spec, 
va_list *args)
 /* This is an implementation of the standard sscanf() function, with the
  * following exceptions:
  *
  *   - It returns true if the entire template was successfully scanned and
  *     converted, false if any conversion failed.
  *
  *   - The standard doesn't define sscanf() behavior when an out-of-range value
@@ -1482,15 +1482,15 @@ scan_chars(const char *s, const struct scan_spec *spec, 
va_list *args)
  *   - %p is not supported.
  */
 bool
-ovs_scan(const char *s, const char *template, ...)
+ovs_scan(const char *s, const char *format, ...)
 {
     const char *const start = s;
     bool ok = false;
     const char *p;
     va_list args;
 
-    va_start(args, template);
-    p = template;
+    va_start(args, format);
+    p = format;
     while (*p != '\0') {
         struct scan_spec spec;
         unsigned char c = *p++;
@@ -1465,7 +1465,7 @@ scan_chars(const char *s, const struct scan_spec *spec, 
  * following exceptions:
  *
- *   - It returns true if the entire template was successfully scanned and
+ *   - It returns true if the entire format was successfully scanned and
  *     converted, false if any conversion failed.
  *
-- 
1.7.9.5

_______________________________________________
dev mailing list
dev@openvswitch.org
http://openvswitch.org/mailman/listinfo/dev

Reply via email to